package com.ruoyi.baseinfo.service;

import java.util.List;
import com.ruoyi.baseinfo.domain.BaseShiftmasterInfo;

/**
 * 交接班基础信息Service接口
 * 
 * @author CaesarBao
 * @date 2020-10-28
 */
public interface IBaseShiftmasterInfoService 
{
    /**
     * 查询交接班基础信息
     * 
     * @param shiftNo 交接班基础信息ID
     * @return 交接班基础信息
     */
    public BaseShiftmasterInfo selectBaseShiftmasterInfoById(String shiftNo);

    /**
     * 查询交接班基础信息列表
     * 
     * @param baseShiftmasterInfo 交接班基础信息
     * @return 交接班基础信息集合
     */
    public List<BaseShiftmasterInfo> selectBaseShiftmasterInfoList(BaseShiftmasterInfo baseShiftmasterInfo);

    /**
     * 新增交接班基础信息
     * 
     * @param baseShiftmasterInfo 交接班基础信息
     * @return 结果
     */
    public int insertBaseShiftmasterInfo(BaseShiftmasterInfo baseShiftmasterInfo);

    /**
     * 修改交接班基础信息
     * 
     * @param baseShiftmasterInfo 交接班基础信息
     * @return 结果
     */
    public int updateBaseShiftmasterInfo(BaseShiftmasterInfo baseShiftmasterInfo);

    /**
     * 批量删除交接班基础信息
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBaseShiftmasterInfoByIds(String ids);

    /**
     * 删除交接班基础信息信息
     * 
     * @param shiftNo 交接班基础信息ID
     * @return 结果
     */
    public int deleteBaseShiftmasterInfoById(String shiftNo);
}
